from .components import orders as Orders
from .components import auth as Auth
from .components import accounts as Accounts
from .components import prices as Prices
from .components import balances as Balances
from .components import transfers as Transfers




from setuptools import setup
import pathlib

# The directory containing this file
HERE = pathlib.Path(__file__).parent

# The text of the README file
README = (HERE / "README.md").read_text()

setup(name='buycoins_client', 
    version='1.2', 
    description='Buycoins API Python client', 
    url='https://github.com/ChukwuEmekaAjah/buycoins_python', 
    author='Chukwuemeka Ajah', 
    author_email='talk2ajah@gmail.com', 
    license='MIT', 
    packages=['buycoins_client'], 
    install_requires=['requests'], 
    zip_safe=True, 
    long_description=README, 
    long_description_content_type='text/markdown'
)